@@ -18,8 +18,9 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 package Test::Reporter;
-
+use 5.005;
 use strict;
+BEGIN{ if (not $] < 5.006) { require warnings; warnings->import } }
 use Cwd;
 use Config;
 use Carp;
@@ -33,7 +34,7 @@ use constant FAKE_NO_NET_DNS => 0;    # for debugging only
 use constant FAKE_NO_NET_DOMAIN => 0; # for debugging only
 use constant FAKE_NO_MAIL_SEND => 0;  # for debugging only
 
-$VERSION = '1.5203';
+$VERSION = '1.54';
 
 local $^W = 1;
 
@@ -45,6 +46,8 @@ sub new {
         '_address'           => 'cpan-testers@perl.org',
         '_grade'             => undef,
         '_distribution'      => undef,
+        # XXX distfile => undef would break old clients :-( -- dagolden, 2009-03-30 
+        '_distfile'          => '', 
         '_report'            => undef,
         '_subject'           => undef,
         '_from'              => undef,
@@ -70,7 +73,7 @@ sub new {
 
     $self->{_attr} = {   
         map {$_ => 1} qw(   
-            _address _distribution _comments _errstr _via _timeout _debug _dir
+            _address _distribution _distfile _comments _errstr _via _timeout _debug _dir
         )
     };
 
@@ -118,7 +121,7 @@ sub _process_params {
 
     my %params   = @_;
     my @defaults = qw(
-        mx address grade distribution from comments via timeout debug dir perl_version transport_args transport );
+        mx address grade distribution distfile from comments via timeout debug dir perl_version transport_args transport );
     my %defaults = map {$_ => 1} @defaults;
 
     for my $param (keys %params) {   
@@ -154,9 +157,10 @@ sub report {
     return $self->{_report} if $self->{_report_lock};
 
     my $report;
-    $report .= "This distribution has been tested as part of the cpan-testers\n";
-    $report .= "effort to test as many new uploads to CPAN as possible.  See\n";
-    $report .= "http://www.cpantesters.org/\n\n";
+    $report .= "This distribution has been tested as part of the CPAN Testers\n";
+    $report .= "project, supporting the Perl programming language.  See\n";
+    $report .= "http://wiki.cpantesters.org/ for more information or email\n"; 
+    $report .= "questions to cpan-testers-discuss\@perl.org\n\n";
 
     if (not $self->{_comments}) {
         $report .= "\n\n--\n\n";
@@ -546,7 +550,7 @@ sub _start_editor {
 
     $editor = $self->_prompt('Editor', $editor);
 
-    die __PACKAGE__, ": The editor `$editor' could not be run" if system "$editor $Report";
+    die __PACKAGE__, ": The editor `$editor' could not be run on '$Report': $!" if system "$editor $Report";
     die __PACKAGE__, ": Report has disappeared; terminated" unless -e $Report;
     die __PACKAGE__, ": Empty report; terminated" unless -s $Report > 2;
 }
@@ -748,65 +752,8 @@ Test::Reporter - sends test results to cpan-testers@perl.org
 =head1 DESCRIPTION
 
 Test::Reporter reports the test results of any given distribution to the CPAN
-Testers. Test::Reporter has wide support for various perl5's and platforms. For
-further information visit the below links:
-
-=over 4
-
-=item * L<http://www.cpantesters.org/>
-
-CPAN Testers reports (new site)
-
-=item * L<http://cpantest.grango.org/>
-
-The new CPAN Testers Wiki (thanks Barbie!)
-
-=item * L<http://lists.cpan.org/showlist.cgi?name=cpan-testers>
-
-The cpan-testers mailing list
-
-=back
-
-Test::Reporter itself--as a project--also has several links for your visiting
-enjoyment:
-
-=over 4
-
-=item * L<http://code.google.com/p/test-reporter/>
-
-Test::Reporter's master project page
-
-=item * L<http://groups.google.com/group/test-reporter>
-
-Discussion group for Test::Reporter
-
-=item * L<http://code.google.com/p/test-reporter/w/list>
-
-The Wiki for Test::Reporter
-
-=item * L<http://eclipse.resort.org/git/gitweb.cgi?p=test-reporter.git>
-
-Test::Reporter's public git source code repository.
-
-=item * L<http://search.cpan.org/dist/Test-Reporter/>
-
-Test::Reporter on CPAN
-
-=item * L<http://code.google.com/p/test-reporter/issues/list>
-
-UNFORTUNATELY, WE ARE UNABLE TO ACCEPT TICKETS FILED WITH RT.
-
-Please file all bug reports and enhancement requests at our Google Code issue
-tracker. Thank you for your support and understanding.
-
-=item * L<http://backpan.cpan.org/authors/id/F/FO/FOX/>
-
-=item * L<http://backpan.cpan.org/authors/id/A/AF/AFOXSON/>
-
-If you happen to--for some strange reason--be looking for primordial versions
-of Test::Reporter, you can almost certainly find them at the above 2 links.
-
-=back
+Testers project. Test::Reporter has wide support for various perl5's and
+platforms. 
 
 =head1 METHODS
 
@@ -1012,8 +959,11 @@ On the machine you are testing from:
 
 On the machine you are submitting from:
 
+  # wrap in an opendir if you've a lot to submit
   my $reporter;
-  $reporter = Test::Reporter->new()->read('pass.Test-Reporter-1.16.i686-linux.2.2.16.1046685296.14961.rpt')->send() || die $reporter->errstr(); # wrap in an opendir if you've a lot to submit
+  $reporter = Test::Reporter->new()->read(
+    'pass.Test-Reporter-1.16.i686-linux.2.2.16.1046685296.14961.rpt'
+  )->send() || die $reporter->errstr(); 
 
 write() also accepts an optional filehandle argument:
 
@@ -1028,20 +978,65 @@ If you experience a long delay sending mail with Test::Reporter, you may be
 experiencing a wait as Test::Reporter attempts to determine your email 
 domain.  Setting the MAILDOMAIN environment variable will avoid this delay.
 
-=head1 COPYRIGHT
-
- Copyright (C) 2008 David A. Golden.
- Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 Adam J. Foxson.
- Copyright (C) 2004, 2005 Richard Soderberg.
- All rights reserved.
-
-=head1 LICENSE
-
-This program is free software; you may redistribute it
-and/or modify it under the same terms as Perl itself.
-
 =head1 SEE ALSO
 
+For more about CPAN Testers:
+
+=over 4
+
+=item * L<http://www.cpantesters.org/>
+
+CPAN Testers reports
+
+=item * L<http://wiki.cpantesters.org/>
+
+CPAN Testers wiki
+
+=back
+
+Test::Reporter itself--as a project--also has several links for your visiting
+enjoyment:
+
+=over 4
+
+=item * L<http://code.google.com/p/test-reporter/>
+
+Test::Reporter's master project page
+
+=item * L<http://groups.google.com/group/test-reporter>
+
+Discussion group for Test::Reporter
+
+=item * L<http://code.google.com/p/test-reporter/w/list>
+
+The Wiki for Test::Reporter
+
+=item * L<http://github.org/dagolden/test-reporter>
+
+Test::Reporter's public git source code repository.
+
+=item * L<http://search.cpan.org/dist/Test-Reporter/>
+
+Test::Reporter on CPAN
+
+=item * L<http://code.google.com/p/test-reporter/issues/list>
+
+UNFORTUNATELY, WE ARE UNABLE TO ACCEPT TICKETS FILED WITH RT.
+
+Please file all bug reports and enhancement requests at our Google Code issue
+tracker. Thank you for your support and understanding.
+
+=item * L<http://backpan.cpan.org/authors/id/F/FO/FOX/>
+
+=item * L<http://backpan.cpan.org/authors/id/A/AF/AFOXSON/>
+
+If you happen to--for some strange reason--be looking for primordial versions
+of Test::Reporter, you can almost certainly find them at the above 2 links.
+
+=back
+
+Related Perl modules:
+
 =over 4
 
 =item * L<perl>
@@ -1082,6 +1077,18 @@ This is optional.  It provides a web API for the 'HTTP' transport method.
  Richard Soderberg <rsod@cpan.org>
  Kurt Starsinic <Kurt.Starsinic@isinet.com>
 
+=head1 COPYRIGHT
+
+ Copyright (C) 2008-2009 David A. Golden.
+ Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 Adam J. Foxson.
+ Copyright (C) 2004, 2005 Richard Soderberg.
+ All rights reserved.
+
+=head1 LICENSE
+
+This program is free software; you may redistribute it
+and/or modify it under the same terms as Perl itself.
+
 =cut
 
 1;
