@@ -1,8 +1,8 @@
 use strict;
-use warnings;
+BEGIN{ if (not $] < 5.006) { require warnings; warnings->import } }
 package Test::Reporter::Transport;
 use vars qw/$VERSION/;
-$VERSION = '1.5202';
+$VERSION = '1.54';
 $VERSION = eval $VERSION;
 
 sub new     { die "Not implemented" }
