@@ -1,9 +1,9 @@
 use strict;
-use warnings;
+BEGIN{ if (not $] < 5.006) { require warnings; warnings->import } }
 package Test::Reporter::Transport::Net::SMTP::TLS;
 use base 'Test::Reporter::Transport::Net::SMTP';
 use vars qw/$VERSION/;
-$VERSION = '1.5202';
+$VERSION = '1.54';
 $VERSION = eval $VERSION;
 
 use Net::SMTP::TLS;
